import os
import sys
import get
# import time, argparse
from optparse import OptionParser
# from typing import Dict

switch = {
    '1': "xhs",
    '2': "weibo",
    '3': "tiktokLive",
}


# 这里应该是获取到一个地址
# 判断地址是pdb文件 还是 directory 地址即可
def task(args):
    mode = 0
    # 1为单个 2为多个  3为批量
    count = 0
    for x in args:
        if str(x).endswith('.pdb'):
            mode = 1
            count += 1
    if count > 1 :
        mode = 2
    if mode == 0:
        if str(args[0]).__contains__("/"):
             mode = 3  #如果方法都没有匹配，那么就是文件夹批量上传
    # 如果模式还是0 那么就是出问题了
    if mode == 0:
        print("输入的参数有误，请检查")
        return
    print("任务开始...")
    if mode == 1:
        get.atom_task(args[0])
    elif mode == 2:
        for x in args:
            get.atom_task(x)
    elif mode == 3:
        dir_url = args[0]
        files = os.listdir(dir_url)
        for x in files:
            if x.endswith(".pdb"):
                get.atom_task(dir_url+x)


    #     读取文件目录，找出所有pdb
    print("任务完毕")


def usage(type):
    if type == "showOption":
        print(''' \033[92m	
               欢迎使用flexpepdock批量下载工具 @Author -nobel 
               	usage : 
                    (1)单个上传 ：flexpatch + 1.pdb
                    (2)多个上传 ：flexpatch + 1.pdb  2.pdb  3.pdb (空格分开即可）
                    (2)批量上传 ：flexpatch + pdb文件所在的目录地址  (会将目录底下的pdb全部上传分析)
                支持相对路径表达方式
               	\033[0m''')

        result = ""
        # while not result.isdigit():
        #     result = input()
        # task(str(switch.get(result)))

    elif type == "help":
        print(''' \033[92m	
        欢迎使用flexpepdock批量下载工具 @Author -nobel 
        	usage : 
        	    没有help咯，help就如开头所示
        	\033[0m''')
    sys.exit()


def get_parameters():
    optp = OptionParser(add_help_option=False, epilog="Hammers")
    optp.add_option("-h", "--help", dest="help", action='store_true', help="help you")
    optp.add_option("-o", "--option", dest="option", action='store_true', help="your option")
    deal_parameters(optp)


def deal_parameters(optp):
    global option
    # 变量和那个都保存在这optp里面
    opts, args = optp.parse_args()
    if opts.help:
        usage("help")
    # elif opts.option is not None:
    #     usage("showOption")
    #     option = opts.option
    elif len(args) == 0:
        usage("showOption")
    else:
        task(args)


# 如何处理相对路径和绝对路径，就是在执行的目录呢，是不是默认支持
if __name__ == '__main__':
    get_parameters()


import requests
from bs4 import BeautifulSoup
# import certifi
from requests_toolbelt import MultipartEncoder

# 重点是这个cookie， 没有的话会被阿里的套件拦截
url = "https://www.ncbi.nlm.nih.gov/protein/AYO18310?report=fasta"

data = {"file" : open("/home/nobel/Downloads/example.pdb", "rb")}

file = ""
# data 参数
# demo: yes
# MAX_FILE_SIZE: 3000000
# upload: (binary)
# sbut: Use Demo File
# eMail: 2097227267@qq.com
# job-name:
# MAX_FILE_SIZE: 3000000
# ref: (binary)
# MAX_FILE_SIZE: 3000000
# con: (binary)
# lownstruct: 100
# highnstruct: 100
# columns[]: total_score
# columns[]: rmsBB
# file = MultipartEncoder(
#     fields={
#             # 'field0': 'value',
#             # 'field1': 'value',
#             'upload': ('file', open("/home/nobel/Downloads/example.pdb", "rb"), 'application/file'),
#             # 'filed3': ("aab.jpg", open("aab.jpg", 'rb'), "image/jpeg")
# })

def post(url):
    headers = {
        "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
        "Accept-Encoding":"gzip, deflate",
        "Accept-Language":"zh-CN,zh;q=0.9",
        "Cache-Control":"max-age=0",
        "user-agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.90 Safari/537.36",
        "Referer":"http://flexpepdock.furmanlab.cs.huji.ac.il/index.php",
        "Host": "flexpepdock.furmanlab.cs.huji.ac.il",
        "Origin":"http://flexpepdock.furmanlab.cs.huji.ac.il",
        "Upgrade-Insecure-Requests":"1",
        "Proxy-Connection":"keep-alive",
    }
    # , verify = certifi.where()
    # result = requests.get(url, headers=headers, data={}, verify=certifi.where(),timeout=30)
    result = requests.post(url,  headers={"Content-Type":file.content_type},data=file)
    return result

# 从单个的开始做,然后再批量
def atom_task(pdb_url):
    global file
    file = MultipartEncoder(
        fields={
            # 'field0': 'value',
            # 'field1': 'value',
            'upload': ('file', open(pdb_url, "rb"), 'application/file'),
            # 'filed3': ("aab.jpg", open("aab.jpg", 'rb'), "image/jpeg")
        })
    res = post('http://flexpepdock.furmanlab.cs.huji.ac.il/saveFile.php').text
    # 这里要把结果号爬出来

    if res.__contains__("You did not succeed in uploading the PDB fil"):
        print("failed, may be the format of your pdb file is wrong")
    else:
        soup = BeautifulSoup(res, "lxml")
        for x in soup.find_all("td"):
            if x.get('id') is not None:
                if x.get('id') == 'content':
                    result_url = x.find_all('a')[1].get('href')
                    # print(x.find_all('a')[1].get('href'))
        print("success, the result url is " + result_url)


if __name__ == '__main__':
    atom_task("/home/nobel/Downloads/example.pdb")
    # atom_task("/home/nobel/Downloads/example.pdb")
    # res = post('http://flexpepdock.furmanlab.cs.huji.ac.il/saveFile.php').text
    # print( res)
    # if res.__contains__("You did not succeed in uploading the PDB fil"):
    #     print("failed")
    # else:
    #     print("success")
    # print(get('http://flexpepdock.furmanlab.cs.huji.ac.il/script.js').text)






from __future__ import print_function
from setuptools import setup, find_packages
import sys

setup(
    name="flexpepdock",
    version="1.0.2",
    author="nobel",
    author_email="nanjilincq@foxmail.com",
    description="A Python library for batch upload for flexpepdock.",
    long_description=open("README.rst").read(),
    license="MIT",
    #url="https://github.com/WEIHAITONG1/better-youtubedl",
    packages=['flexpepdock'],
    classifiers=[
        "Environment :: Web Environment",
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: MacOS',
        'Operating System :: Microsoft',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Topic :: Multimedia :: Video',
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries :: Python Modules",
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
         'Programming Language :: Python :: 3.7',
         'Programming Language :: Python :: 3.8',
    ],
    zip_safe=True,
    install_requires=[
	'requests_toolbelt', 'bs4', 'requests'
    ]
)
